# Change Log

All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [Released]

### Added
- Storing/Loading program from JSON files (program_N.json where N=[1..4])
- Load BLE module to accept incoming requests from android BLE modules
- Load Wifi client to connect to the configured Wifi networks

### Changed
- version 1.0.6
- part patch

### Fixed
- Bug in release.yml workflow

## [1.0.6] - 2024-01-21

### Added
- Initial release
